summaryrefslogtreecommitdiff
path: root/examples/set_avatar.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/set_avatar.py')
-rwxr-xr-xexamples/set_avatar.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/examples/set_avatar.py b/examples/set_avatar.py
index cae93c99..647bbd8c 100755
--- a/examples/set_avatar.py
+++ b/examples/set_avatar.py
@@ -2,9 +2,9 @@
# -*- coding: utf-8 -*-
"""
SleekXMPP: The Sleek XMPP Library
Copyright (C) 2012 Nathanael C. Fritz
- This file is part of SleekXMPP.
+ This file is part of Slixmpp.
See the file LICENSE for copying permission.
"""
@@ -17,29 +17,29 @@ import getpass
import threading
from optparse import OptionParser
-import sleekxmpp
-from sleekxmpp.exceptions import XMPPError
+import slixmpp
+from slixmpp.exceptions import XMPPError
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
# throughout SleekXMPP, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):
- from sleekxmpp.util.misc_ops import setdefaultencoding
+ from slixmpp.util.misc_ops import setdefaultencoding
setdefaultencoding('utf8')
else:
raw_input = input
-class AvatarSetter(sleekxmpp.ClientXMPP):
+class AvatarSetter(slixmpp.ClientXMPP):
"""
A basic script for downloading the avatars for a user's contacts.
"""
def __init__(self, jid, password, filepath):
- sleekxmpp.ClientXMPP.__init__(self, jid, password)
+ slixmpp.ClientXMPP.__init__(self, jid, password)
self.add_event_handler("session_start", self.start, threaded=True)
@@ -2,9 +2,9 @@
# -*- coding: utf-8 -*-
"""
- SleekXMPP: The Sleek XMPP Library
+ Slixmpp: The Slick XMPP Library
Copyright (C) 2012 Nathanael C. Fritz
@@ -17,29 +17,29 @@ import getpass
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
-# throughout SleekXMPP, we will set the default encoding
+# throughout Slixmpp, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):